@@ -125,7 +125,7 @@ namespace Arc {
     if(!result) return result;
     if(check_meta) {
       FileInfo file;
-      if(Stat(file, DataPoint::INFO_TYPE_CONTENT)) {
+      if(Stat(file, (DataPoint::DataPointInfoType)(DataPoint::INFO_TYPE_CONTENT | DataPoint::INFO_TYPE_TIMES))) {
         if(file.CheckModified()) SetModified(file.GetModified());
         if(file.CheckSize()) SetSize(file.GetSize());
       }
@@ -322,7 +322,7 @@ namespace Arc {
           logger.msg(DEBUG, "StopWriting: "
                             "looking for checksum of %s", url.plainstr());
           FileInfo info;
-          if(Stat(info, DataPoint::INFO_TYPE_CONTENT)) {
+          if(Stat(info, DataPoint::INFO_TYPE_CKSUM)) {
             if(info.CheckCheckSum()) {
               if(csum.length() != info.GetCheckSum().length()) {
                 // Some buggy Globus servers return a different type of checksum to the one requested
